@@ -116,6 +116,15 @@ myobj_destroy (ASHashableValue value, void *data)
 		}
 	}
 }
+
+ARGB32
+get_random_tint_color()
+{	
+	static ARGB32 tint_colors[6] = {0xFFFF0000,0xFFFFFF00,0xFFFF00FF,0xFF00FFFF,0xFF00FF00,0xFF0000FF};
+	return tint_colors[time(NULL)%6] ;
+}
+	
+
 /*************************************************************************/
 /* MyLook :                                                              */
 /*************************************************************************/
@@ -263,11 +272,25 @@ mylook_init (MyLook * look, Bool free_resources, unsigned long what_flags /*see
 
 	if (get_flags (what_flags, LL_Misc))
 	{
+		CARD32 Base ;
 		look->RubberBand = 0;
 		look->CursorFore = NULL ;
 		look->CursorBack = NULL ;
+		if( !get_custom_color("Base", &Base) ) 
+			look->desktop_animation_tint = get_random_tint_color() ;
+		else
+		{
+			int Base_hue ;
+			Base_hue = asxml_var_get("ascs.Base.hue");
+			if( Base_hue < 30 || Base_hue >= 330 ) 	look->desktop_animation_tint = 0xFFFF0000;
+			else if( Base_hue < 90  ) 	look->desktop_animation_tint = 0xFFFFFF00;
+			else if( Base_hue < 150  ) 	look->desktop_animation_tint = 0xFF00FF00;
+			else if( Base_hue < 210  ) 	look->desktop_animation_tint = 0xFF00FFFF;
+ 			else if( Base_hue < 270  ) 	look->desktop_animation_tint = 0xFF0000FF;
+			else look->desktop_animation_tint = 0xFFFF00FF;
+		}
     }
-
+	LOCAL_DEBUG_OUT( "desk_anime_tint = %lX", look->desktop_animation_tint );
 	if (get_flags (what_flags, LL_Flags))
 		look->flags = SeparateButtonTitle | TxtrMenuItmInd;
 
@@ -317,6 +340,9 @@ create_myframe()
 	frame->left_layout = MYFRAME_DEFAULT_TITLE_LAYOUT ;
 	frame->right_layout = MYFRAME_DEFAULT_TITLE_LAYOUT ;
 
+	frame->title_fsat = frame->title_usat = frame->title_ssat = -1 ;
+	frame->title_fhue = frame->title_uhue = frame->title_shue = -1 ;
+
     return frame;
 
 }
@@ -362,6 +388,8 @@ create_default_myframe(ASFlagType default_title_align)
     frame->title_ubevel = DEFAULT_TBAR_HILITE;
     frame->title_sbevel = DEFAULT_TBAR_HILITE;
     frame->title_align = default_title_align;
+	frame->left_btn_align = ALIGN_VCENTER ;
+	frame->right_btn_align = ALIGN_VCENTER ;
     frame->title_fcm = TEXTURE_TRANSPIXMAP_ALPHA;
     frame->title_ucm = TEXTURE_TRANSPIXMAP_ALPHA;
     frame->title_scm = TEXTURE_TRANSPIXMAP_ALPHA;
@@ -425,6 +453,11 @@ inherit_myframe( MyFrame *frame, MyFrame *ancestor )
 
         if( get_flags( ancestor->set_title_attr, MYFRAME_TitleAlignSet ) )
             frame->title_align = ancestor->title_align;
+        
+		if( get_flags( ancestor->set_title_attr, MYFRAME_LeftBtnAlignSet ) )
+            frame->left_btn_align = ancestor->left_btn_align;
+		if( get_flags( ancestor->set_title_attr, MYFRAME_RightBtnAlignSet ) )
+            frame->right_btn_align = ancestor->right_btn_align;
 
         if( get_flags( ancestor->set_title_attr, MYFRAME_CondenseTitlebarSet ) )
             frame->condense_titlebar = ancestor->condense_titlebar;
@@ -436,6 +469,20 @@ inherit_myframe( MyFrame *frame, MyFrame *ancestor )
         if( get_flags( ancestor->set_title_attr, MYFRAME_TitleSCMSet ) )
             frame->title_scm = ancestor->title_scm;
 
+        if( get_flags( ancestor->set_title_attr, MYFRAME_TitleFHueSet ) )
+            frame->title_fhue = ancestor->title_fhue;
+        if( get_flags( ancestor->set_title_attr, MYFRAME_TitleUHueSet ) )
+            frame->title_uhue = ancestor->title_uhue;
+        if( get_flags( ancestor->set_title_attr, MYFRAME_TitleSHueSet ) )
+            frame->title_shue = ancestor->title_shue;
+        if( get_flags( ancestor->set_title_attr, MYFRAME_TitleFSatSet ) )
+            frame->title_fsat = ancestor->title_fsat;
+        if( get_flags( ancestor->set_title_attr, MYFRAME_TitleUSatSet ) )
+            frame->title_usat = ancestor->title_uhue;
+        if( get_flags( ancestor->set_title_attr, MYFRAME_TitleSSatSet ) )
+            frame->title_ssat = ancestor->title_ssat;
+
+
         frame->set_title_attr |= ancestor->set_title_attr ;
 
 		clear_flags( frame->flags, ~ancestor->set_flags );
@@ -649,7 +696,10 @@ void myback_delete( MyBackground **myback, ASImageManager *imman )
 			if( ASDefaultScr->RootBackground && ASDefaultScr->RootBackground->pmap == (*myback)->loaded_pixmap )
 			{	
 	            if( ASDefaultScr->wmprops && ASDefaultScr->wmprops->root_pixmap == ASDefaultScr->RootBackground->pmap )
+				{	
     	            set_xrootpmap_id (ASDefaultScr->wmprops, None );
+					set_as_background(ASDefaultScr->wmprops, None );
+				}
 				ASDefaultScr->RootBackground->pmap = None;
 			}
 			destroy_visual_pixmap( ASDefaultVisual, &((*myback)->loaded_pixmap) );
